Page 11 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 11

Home

    14 And he carried away all Jerusalem, and all the princes,
    and all the mighty men of valor, even ten thousand
    captives, and all the craftsmen and smiths; none
    remained, save the poorest sort of the people of the land.

    This was history's first recorded deportation. Later,
    during the reign of King Zedekiah, the Babylonians
    returmed, destroyed the city of Jerusalem, and took the
    remaining inhabitants captive to Babylon.

    Daniel was in the first group of captives taken from
    Jerusalem to Babylon (606 B.C.). Here he spent the rest
    of his life (70 years). Although unswerving in his own
    religious convictions, Daniel held high positions in the
    government under several Babylonian kings. It was in
    this city that Daniel was thrown into the lion's den, and
    Shadrack, Meshack, and Abed-nego were cast into the

    fiery furnace.

    Twelve manuscripts of Isaiah and fragments of the
    Book of Daniel were found among the Dead Sea Scrolls.
    The first discovery of these scrolls in 1947 led to the
    exploration of eleven caves near the Dead Sea.
    Altogether, these efforts yielded hundreds of manuscripts
    dating from the last century B.C. and first century A.D.
    This find has been hailed as one of the most important

    discoveries of Old Testament manuscripts. Many works
    found during this period have been published and are
    available for study either in translation or in facsimile.
    These scrolls substantiate the historical events of the Old

    The Secret Side of History

    Testament as recorded by Isaiah and Daniel.